﻿var Conference = Conference || {};

Conference.Contacts = function ($, kendo) {
	/// <summary>
	/// Contacts module to allow the user to add contacts and display contacts
	/// that were added from within this app.
	/// </summary>

    var _initialized = false,
		CATEGORY = "Test 4"; // DMVMUG2014

    var init = function () {
		/// <summary>
		/// Initialize the Contacts module and display the list of contacts.
		/// </summary>

        if (!_initialized) {
            $("#contacts header button").on("click", function () {
				/// <summary>
				/// + button clicked.  Display the Add Contact dialog.
				/// </summary>
				
				$("#addContactDetails input").val("");

                $("#addContact").show();
            });

            $("#addContact button:first").on("click", function () {
				/// <summary>
				/// X button clicked.  Hide the Add Contact dialog.
				/// </summary>

                $("#addContact").hide();
            });

            $("#addContactMenu button").on("click", function () {
				/// <summary>
				/// Save button clicked.  Hide the Add Contact dialog and add the contact.
				/// </summary>

                $("#addContact").hide();
				addContact();
            });
			
			_initialized = true;
        }

		displayList();
    };

    displayList = function () {
		/// <summary>
		/// Display the list of contacts that have been added from within this app.
		/// </summary>

		/// Filter by the category.
        var filter = {
            filterBy: ["category"],
            filterValue: CATEGORY,
            filterOp: "equals",
            filterLimit: 100
        };

        var search = window.navigator.mozContacts.find(filter);

        search.onsuccess = function () {
			/// <summary>
			/// Display the list of contacts returned from the ContactManager.
			/// </summary>

			var $contactList = $("#contactList"),
				template = kendo.template($("#contactListEntry").html());

			$contactList.empty();

			for (var idx = 0; idx < search.result.length; idx++) {
				$contactList.append(template(search.result[idx]));
			}
        }

        search.onerror = function () {
            console.log("FAILED to get the list of contacts!");
        }
    };

	var addContact = function () {
		/// <summary>
		/// Add a new contact.
		/// </summary>
		
        var person = new mozContact(),
			value;

        person.givenName = $("#addContactGivenName").val();
        person.familyName = $("#addContactFamilyName").val();
        person.category = [CATEGORY];
		person.tel = [];
		person.email = [];
		
		value = $("#addContactCellPhone").val();
		if (value.length > 0) {
			person.tel.push(	{ type: "cell", value: value });
		}
		value = $("#addContactWorkPhone").val();
		if (value.length > 0) {
			person.tel.push(	{ type: "work", value: value });
		}
		value = $("#addContactHomePhone").val();
		if (value.length > 0) {
			person.tel.push(	{ type: "home", value: value });
		}
		
		value = $("#addContactWorkEmail").val();
		if (value.length > 0) {
			person.email.push({ type: "work", value: value });
		}
		value = $("#addContactHomeEmail").val();
		if (value.length > 0) {
			person.email.push({ type: "home", value: value });
		}

        var request = window.navigator.mozContacts.save(person);

        request.onsuccess = function () {
			/// <summary>
			/// If the contact was successfully saved, then display
			/// the list of contacts with the new contact.
			/// </summary>
			
            console.log("New Contact Added");
			displayList();
        }

        request.onerror = function () {
            console.log("FAILED to add new contact!");
        }
	};

    return {
        init: init,
    };
}(kendo.jQuery, kendo);
