﻿var Conference = Conference || {};

Conference.Sessions = function ($, kendo) {
	/// <summary>
	/// Sessions module to display the list of sessions for this conference.
	/// </summary>

    var _sessions,
        _initialized = false;

    var init = function () {
		/// <summary>
		/// Initialize the Sessions module and display the list session groups.
		/// </summary>

        if (!_initialized) {
            _sessions = Conference.Data.sessions();
            var groups = group(_sessions);

            displayGroups(groups);

            $("#sessionList").on("click", "a", function () {
				/// <summary>
				/// A session is selected.  Display the session details.
				/// </summary>
				
                var $link = $(this),
                    id = $link.attr("data-id"),
                    session = Enumerable.From(_sessions)
                        .Where(function (session) { return session.id == id; })
                        .FirstOrDefault();
                kendo.bind($("#sessionDetails"), session);

                $("#details").show();
            });

            var $sidebarList = $("#sidebarList"),
                tracks = Conference.Data.tracks();

            for (var idx = 0; idx < tracks.length; idx++) {
                $sidebarList.append(kendo.format("<li><a>{0}</a></li>", tracks[idx]));
            }

            $sidebarList.on("click", "a", function () {
                var $a = $(this);
                $("#sessionSearchText").val($a.text());
                window.location.hash = "#sessions";
                filterSessions();
            });

            $("#detailsMenu button").on("click", function () {
                $("#details").hide();
            });

            $("#sessionSearch").on("keypress", function (e) {
                if (e.which === 13) {
                    e.preventDefault();
                    filterSessions();
                } else {
                    return;
                }
            });

            $("#sessionSearch").on("submit", function () {
                var $searchText = $("#sessionSearchText");
                if ($searchText.val().length > 0) {
                    $searchText.val("");
                    displayGroups(group(_sessions));
                }
            });

            _initialized = true;
        }
    };

    var filterSessions = function () {
        var searchText = $("#sessionSearchText").val(),
            sessions = searchText.length > 0
                ? Enumerable.From(_sessions)
                    .Where(function (session) {
                        return session.title.indexOf(searchText) !== -1
                            || session.track.indexOf(searchText) !== -1
                            || (session.description && session.description.indexOf(searchText) !== -1);
                    })
                    .ToArray()
                : _sessions;
        displayGroups(group(sessions));
    };

    var group = function (sessions) {
        return Enumerable.From(sessions)
            .GroupBy(function (session) { return session.time; },
                        function (session) {
                            return {
                                id: session.id,
                                track: session.track,
                                title: session.title
                            };
                        },
                    function (time, grouping) {
                        return {
                            time: time,
                            sessions: grouping.ToArray()
                        };
                    })
            .ToArray();
    };

    var displayGroups = function (groups) {
        var template = kendo.template($("#sessionListGroup").html()),
            $sessionList = $("#sessionList");

        $sessionList.empty();

        for (var idx = 0; idx < groups.length; idx++) {
            $sessionList.append(template(groups[idx]));
        }
    };

    return {
        init: init,
        sessions: function () { return _sessions; }
    };
}(kendo.jQuery, kendo);
